import requests
import json
import jwt
import datetime
import os

from bitmath import MiB

from aep_sdk.ParameterClasses.AuthToken import AuthToken
from aep_sdk.ParameterClasses.Dataset import Dataset
from aep_sdk.Tools.Cataloguer import Cataloguer
from aep_sdk.Tools.Ingestor import Ingestor


class API:
    """
    The handler for the entire SDK.

    Attributes:
        access_token (AuthToken): The user's current active authorization token.
        api_key (str): The user's API Key for the Adobe Experience Platform.
        aud (str): The audience for the JWT token.
        cataloguer (Cataloguer): A Cataloguer object used for reporting.
        client_secret (str): The client_secret id of the user.
        ims_org (str): The IMS Organization email of the user.
        ingestor (Ingestor): An Ingestor object used for the handling of uploading files.
        jwt_token (str): The current JWT token.
        secret (str): The user's secret key used for the creation of JWT tokens.
        sub (str): The user's Technical Account id for Adobe I/O.

    Quick Methods:
        access(self):
            A function that generates and Auth Token for the current user.
        get_datasets(self):
            A function that queries and returns a list of datasets that are assigned to the current user.
        init_config(self, config_file):
            A function that initializes the config file and checks it for errors.
        report(self, identification):
            Runs the cataloguer report function, which will wait until the batch finishes loading before
             printing the batch status.
        upload(self, files, dataset_id, blocking):
            A function which uploads the given files to the given dataset ID using the ingestor.
        validate(self, data_set_id):
            A function that checks if a given dataset ID exists for the current account.
    """

    def __init__(self, config_file):
        """
        Constructs all the necessary attributes for an API object.

        Args:
            config_file (str): The full name and path of the config file.
        """
        self.api_key = None
        self.client_secret = None
        self.ims_org = None
        self.sub = None
        self.secret = None
        self.aud = None

        if not self.init_config(config_file):
            print("Bad config file")
            exit(0)

        payload = {
            "exp": datetime.datetime.utcnow() + datetime.timedelta(seconds=600),
            "iss": self.ims_org,
            "sub": self.sub,
            "https://ims-na1.adobelogin.com/s/ent_dataservices_sdk": True,
            "aud": self.aud
        }
        self.jwt_token = jwt.encode(payload, self.secret, algorithm='RS256').decode('utf-8')
        self.access_token = self.access()
        self.cataloguer = Cataloguer()
        self.ingestor = Ingestor()
        
    def init_config(self, config_file):
        """
        A function that initializes the config file and checks it for errors.

        Args:
            config_file (str): The full name and path of the config file.

        Returns:
            initialized (bool): A boolean stating if the config was successfully initialized or not.
        """

        with open(config_file) as json_data_file:
            data = json.load(json_data_file)
        if not data.get('api_key'):
            return False
        self.api_key = data['api_key']
        if not self.validate_string(self.api_key):
            return False
        if not data.get('client_secret'):
            return False
        self.client_secret = data['client_secret']
        if not self.validate_string(self.client_secret):
            return False
        if not data.get('ims_org'):
            return False
        self.ims_org = data['ims_org']
        if not self.validate_string(self.ims_org):
            return False
        if not data.get('sub'):
            return False
        self.sub = data['sub']
        if not self.validate_string(self.sub):
            return False
        if not data.get('secret'):
            return False
        self.secret = data['secret']
        if not self.validate_string(self.secret):
            return False
        self.aud = 'https://ims-na1.adobelogin.com/c/' + self.api_key
        return True

    def validate_string(self, obj):
        """
        A helper function that checks if an object from the config json file is not null or the empty string.

        Args:
            obj (str): The string we are validating.

        Returns:
            valid (bool): A boolean stating if the object was null/empty or not.
        """
        if obj is None or obj == "":
            return False
        return True

    def report(self, identification, full_response=False):
        """
        Runs the cataloguer report function, which will wait until the batch finishes loading before printing
         the batch status.

        Args:
            identification (str): The dataset ID of the batch to report on.
            full_response (bool): Whether or not to print the whole json response for querying a batch status.
        """
        self.cataloguer.report(identification, self.ims_org, self.access_token, self.api_key, full_response)

    def validate(self, data_set_id):
        """
        A function that checks if a given dataset ID exists for the current account.

        Args:
            data_set_id (str): A dataset ID to validate.

        Returns:
            exists (bool): A boolean stating whether the dataset ID exists on the current account.
        """
        if data_set_id == "":
            print("You need to enter a DataSetID.")
            return False
        headers = {
            'Authorization': 'Bearer ' + self.access_token.get_token(),
            'x-api-key': self.api_key,
            'x-gw-ims-org-id': self.ims_org,
        }
        params = (
            ('properties', 'name,description,state,tags,files'),
        )
        response = requests.get('https://platform.adobe.io/data/foundation/catalog/dataSets/' + data_set_id,
                                headers=headers, params=params)
        if not self.error_check_json(response):
            return False
        return True

    def access(self):
        """
        A function that generates an Auth Token for the current user.

        Returns:
            authorization (AuthToken): An valid authorization token for the current user that will last for 24 hours.
        """
        files = {
            'client_id': (None, self.api_key),
            'client_secret': (None, self.client_secret),
            'jwt_token': (None, self.jwt_token),
        }
        test_data = requests.post('https://ims-na1.adobelogin.com/ims/exchange/jwt/', files=files)
        if not self.error_check_json(test_data):
            exit(0)
        name = test_data.json()['access_token']
        expiration = test_data.json()['expires_in']
        expiration_date = datetime.datetime.utcnow() + datetime.timedelta(milliseconds=expiration - 1000)
        authorization = AuthToken(name, expiration, expiration_date)
        return authorization

    def get_datasets(self, limit=5):
        """
        A function that queries and returns a list of datasets that are assigned to the current user.

        Returns:
            datasets (list): A list of datasets belonging to the current account.
        """
        headers = {
            'Authorization': 'Bearer ' + self.access_token.get_token(),
            'x-api-key': self.api_key,
            'x-gw-ims-org-id': self.ims_org,
        }
        params = (
            ('limit', limit),
            ('properties', 'name'),
        )
        response = requests.get('https://platform.adobe.io/data/foundation/catalog/dataSets',
                                headers=headers, params=params)
        ids = []
        if not self.error_check_json(response):
            exit(0)
        for response_id in response.json():
            ids.append(Dataset(response_id, response.json()[response_id]['name']))
        return ids

    def upload(self, files, dataset_id, blocking=True):
        """
        A function which uploads the given json files to the given dataset ID using the ingestor.

        Args:
            files (list): A list of strings which are the full path and names of the files being uploaded.
            dataset_id (str): The dataset ID that is being uploaded to.
            blocking (bool): Whether or not to block and wait for a report of the upload success or failure.

        Returns:
            response (str): The response from the Experience platform stating whether a batch succeeded or failed.
        """
        if not self.validate(dataset_id):
            exit(0)
        batch_id = self.ingestor.start_batch(dataset_id, self.ims_org, self.access_token, self.api_key)
        for fileName in files:
            if os.path.getsize(fileName) <= MiB(256).to_Byte():
                self.ingestor.upload(fileName, batch_id, dataset_id, self.ims_org, self.access_token, self.api_key)
            else:
                self.ingestor.upload_large(fileName, batch_id, dataset_id, self.ims_org,
                                           self.access_token, self.api_key)
        return self.ingestor.finish_upload(batch_id, self.ims_org, self.access_token, self.api_key,
                                           self.cataloguer, blocking)

    def error_check_json(self, response):
        """
        A helper function which checks the given response object for errors and prints what those errors are.

        Args:
            response (Response): A Response object from the requests library.

        Returns:
            valid (bool): A boolean stating whether there was an error in the request or not.
        """
        if response.json().get('error'):
            print('Error: ' + response.json()['error_description'])
            return False
        if response.json().get('error_code'):
            print('Error: ' + response.json()['message'])
            return False
        if response.json().get('title'):
            if response.json()['title'] == "NotFoundError":
                print('Error: ' + response.json()['detail'])
                return False
        return True



import abc

from aep_sdk.ParameterClasses.AuthToken import AuthToken


class IngestorInterface(abc.ABC):

    @abc.abstractmethod
    def upload(self, file_name, batch_id, dataset_id, ims_org, access_token: AuthToken, api_key):
        pass
#   def upload(self, file, schema:Schema, dataSetID:DataSetId, authToken:AuthToken):
#       pass #File is fileInputScheme



import requests
import os
import json
import csv

from _csv import QUOTE_ALL
from bitmath import MiB

from aep_sdk.Interfaces.IngestorInterface import IngestorInterface
from aep_sdk.ParameterClasses.AuthToken import AuthToken


class Ingestor(IngestorInterface):
    """
    An object that handles the uploading of files to the Adobe Experience Platform.

    Quick Methods:
        error_check(self, response):
            A function that checks if a response object was valid.
        finish_upload(self, batch_id, ims_org, access_token: AuthToken, api_key, cataloguer, blocking):
            A function that signals the completion of the batch.
        new_split(self, file_name):
            A function that splits up JSON files of sizes greater than 256MB.
        send_file(self, file_name, batch_id, dataset_id, ims_org, access_token: AuthToken, api_key):
            A function that sends the file to a batch to be uploaded.
        start_batch(self, dataset_id, ims_org, access_token: AuthToken, api_key):
            A function that creates the batch that the files will upload to.
        upload(self, file_name, batch_id, dataset_id, ims_org, access_token:AuthToken, api_key):
            A function that handles the uploading of files of sizes less than or equal to 256MB.
        upload_large(self, file_name, batch_id, dataset_id, ims_org, access_token:AuthToken, api_key):
            A function that handles the uploading of files of sizes greater than 256MB.
    """

    def __init__(self):
        """
        Constructs all the necessary attributes for an Ingestor object.
        """
        self.current_index = 0
        pass

    def start_batch(self, dataset_id, ims_org, access_token: AuthToken, api_key):
        """
        A function that creates the batch that the files will upload to.

        Args:
            dataset_id (str): The string that is the dataset ID that is being uploaded to.
            ims_org (str): The IMS Organization email of the user.
            access_token (AuthToken): The user's current active authorization token.
            api_key (str): The user's API Key for the Adobe Experience Platform.

        Returns:
            batch_id (str): A string that is the id of the batch that has just been created.
        """

        headers = {
            'Content-Type': 'application/json',
            'x-gw-ims-org-id': ims_org,
            'Authorization': 'Bearer ' + access_token.get_token(),
            'x-api-key': api_key
        }
        data = '{\n          "datasetId": "'\
               + dataset_id\
               + '",\n           "inputFormat": {\n' \
               + '                "format": "json",\n' \
               + '                "isMultiLineJson": true\n           }\n      }'
        response = requests.post('https://platform.adobe.io/data/foundation/import/batches', headers=headers, data=data)
        batch_id = response.json()['id']
        print('Batch ID: ' + str(batch_id))
        return batch_id

    def send_file(self, file_name, batch_id, dataset_id, ims_org, access_token: AuthToken, api_key):
        """
        A function that sends the file to a batch to be uploaded.

        Args:
            file_name (str): The full name and path of the file to be uploaded.
            batch_id (str): The id of the batch that the file is being sent to.
            dataset_id (str): The id of the dataset that is being uploaded to.
            ims_org (str): The IMS Organization email of the user.
            access_token (AuthToken): The user's current active authorization token.
            api_key (str): The user's API Key for the Adobe Experience Platform.

        Returns:
            response (Response): The response object given by the put request to the Adobe Experience Platform.
        """

        headers = {
            'Content-Type': 'application/octet-stream',
            'x-gw-ims-org-id': ims_org,
            'Authorization': 'Bearer ' + access_token.get_token(),
            'x-api-key': api_key
        }
        print('File upload of ' + os.path.basename(file_name) + ' in progress')
        file = open(file_name, 'rb')
        data = file.read()
        file.close()
        response = requests.put('https://platform.adobe.io/data/foundation/import/batches/' + batch_id + '/datasets/'
                                + dataset_id + '/files/' + os.path.basename(file_name), headers=headers, data=data)
        return response

    def finish_upload(self, batch_id, ims_org, access_token: AuthToken, api_key, cataloguer, blocking=True):
        """
        A function that signals the completion of the batch.

        Args:
            batch_id (str): The id of the batch currently being uploaded.
            ims_org (str): The IMS Organization email of the user.
            access_token (AuthToken): The user's current active authorization token.
            api_key (str): The user's API Key for the Adobe Experience Platform.
            cataloguer (Cataloguer): A Cataloguer object used for reporting the batch status.
            blocking (bool): Whether or not to block and wait for a report of the upload success or failure.

        Returns:
            status (str): The string of the batch status given by the cataloguer's report function.
        """

        headers = {
            'x-gw-ims-org-id': ims_org,
            'Authorization': 'Bearer ' + access_token.get_token(),
            'x-api-key': api_key
        }
        params = (
            ('action', 'COMPLETE'),
        )
        response = requests.post('https://platform.adobe.io/data/foundation/import/batches/' + batch_id,
                                 headers=headers, params=params)
        if not self.error_check(response):
            print("Signal Completion has failed for " + batch_id)
            return "Failed"
        else:
            print(batch_id + " upload started successfully")
        if blocking:
            return cataloguer.report(batch_id, ims_org, access_token, api_key)
        else:
            print("Your Upload is in Progress")
            return "In Progress"

    def upload(self, file_name, batch_id, dataset_id, ims_org, access_token: AuthToken, api_key):
        """
        A function that handles the uploading of files of sizes less than or equal to 256MB.

        Args:
            file_name (str): The full name and path of the file being uploaded.
            batch_id (str): The id of the batch that is being used.
            dataset_id (str): The id of the dataset that is being uploaded to.
            ims_org (str): The IMS Organization email of the user.
            access_token (AuthToken): The user's current active authorization token.
            api_key (str): The user's API Key for the Adobe Experience Platform.
        """
        response = self.send_file(file_name, batch_id, dataset_id, ims_org, access_token, api_key)
        if not self.error_check(response):
            return

    def upload_large(self, file_name, batch_id, dataset_id, ims_org, access_token: AuthToken, api_key):
        """
        A function that handles the uploading of files of sizes greater than 256MB.

        Args:
            file_name (str): The full name and path of the file being uploaded.
            batch_id (str): The id of the batch that is being used.
            dataset_id (str): The id of the dataset that is being uploaded to.
            ims_org (str): The IMS Organization email of the user.
            access_token (AuthToken): The user's current active authorization token.
            api_key (str): The user's API Key for the Adobe Experience Platform.
        """
        if file_name.lower().endswith(".json"):
            self.json_split(file_name)
        for entry in os.scandir('Splits/'):
            response = self.send_file(entry.path, batch_id, dataset_id, ims_org, access_token, api_key)
            if not self.error_check(response):
                print(os.path.basename(entry.path) + ' failed to upload')
                continue
            os.remove(entry.path)
        os.rmdir('Splits/')

    def error_check(self, response):
        """
        A function that checks if a response object was valid.

        Args:
            response (Response): A response object from the requests library.

        Returns:
            valid (bool): A boolean stating whether there was an error code or not.
        """
        if response.status_code != 200:
            print("Error: " + response.status_code)
            return False
        return True

    def _one_pass(self, iterators):
        """
        Helper for the new_split function.
        """
        i = 0
        while i < len(iterators):
            try:
                yield next(iterators[i])
            except StopIteration:
                del iterators[i]
            else:
                i += 1

    def zip_var_len(self, *iterables):
        """
        Helper for the new_split function.
        """
        iterators = [iter(it) for it in iterables]
        while True:
            val = tuple(self._one_pass(iterators))
            if val:
                yield val
            else:
                break

    def grouper(self, iterable, n):
        """
        Helper for the new_split function.
        """
        "Collect data into fixed-length chunks or blocks"
        args = [iter(iterable)] * n
        return self.zip_var_len(*args)

    def json_split(self, file_name):
        """
        A function that splits up JSON files of sizes greater than 256MB.

        Args:
            file_name: The full name and path of the file being split.
        """
        file = open(file_name, 'rb')
        values = file.read()
        file.close()
        v = json.loads(values)
        os.mkdir('Splits/')
        for i, group in enumerate(self.grouper(v, 125000)):
            self.current_index = self.current_index + 1
            with open('Splits/' + os.path.splitext(os.path.basename(file_name))[0]
                      + '_{}.json'.format(self.current_index), 'w') as output_file:
                json.dump(list(group), output_file)



import requests
import time

from aep_sdk.Interfaces.CataloguerInterface import CataloguerInterface


class Cataloguer(CataloguerInterface):
    """
    An object that handles the reporting from the Adobe Experience Platform.

    Quick Methods:
        report(self, identification, ims_org, access_token, api_key):
            A function that checks and sends back the status of a batch.
    """

    def __init__(self):
        """
        Constructs all the necessary attributes for a Cataloguer object.
        """
        pass

    def report(self, identification, ims_org, access_token, api_key, full_response=False):
        """
        A function that checks and sends back the status of a batch.

        Args:
            identification (str): The id of the batch that is being checked.
            ims_org (str): The IMS Organization email of the user.
            access_token (AuthToken): The user's current active authorization token.
            api_key (str): The user's API Key for the Adobe Experience Platform.
            full_response (bool):  Whether or not to print the whole json response for querying a batch status.

        Returns:
            status (str): A string that is the status of the given batch.
        """

        headers = {
            'x-gw-ims-org-id': ims_org,
            'Authorization': 'Bearer ' + access_token.get_token(),
            'x-api-key': api_key
        }
        finished = False
        response = None
        while not finished:
            time.sleep(5)
            response = requests.get('https://platform.adobe.io/data/foundation/catalog/batches/' + identification,
                                    headers=headers)
            finished = False
            for idNum in response.json():
                if response.json()[idNum]['status'] == "loaded" or response.json()[idNum]['status'] == "loading"\
                        or response.json()[idNum]['status'] == "staging":
                    continue
                else:
                    finished = True
                    break
        for idNum in response.json():
            if full_response:
                print(response.json())
            print('Batch Status: ' + response.json()[idNum]['status'])
            return response.json()[idNum]['status']



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name='aep_sdk',
    version='0.0.35',
    description='A SDK for the Adobe Experience Platform',
    long_description=long_description,
    long_description_content_type="text/markdown",
    install_requires=[
        "requests",
        "PyJWT",
        "bitmath",
        "cryptography",
    ],
    liscense='MIT',
    url='https://github.com/Dacson33/Experience-Platform-Python-SDK/',
    author=[
        "Dakoda Richardson",
        "Benson Condie",
        "Adam Ure",
        "Nick Cummings",
        "Lance Haderlie"
    ],
    python_requires='>=3.7',
    classifiers=[
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Operating System :: OS Independent",
        "Topic :: Utilities",
        "License :: OSI Approved :: MIT License",
    ],
    packages=setuptools.find_packages(
        exclude=['Tests']
    ),
)



import datetime


class AuthToken:
	"""
	Holds all the information about an Authentication Token for the Adobe Experience Platform.

	Attributes:
		token (str): The actual token used for authentication.
		expiration (int): The number of milliseconds this token is valid for.
		expiration_date (datetime.pyi): The datetime that this token expires.
	Quick Methods:
		get_expiration(self):
			Simple getter for expiration.
		get_expirationDate(self):
			Simple getter for expiration_date.
		get_token(self):
			Simple getter for token.
	"""
	def __init__(self, token, expiration, expiration_date):
		"""
		Constructs all the necessary attributes for an AuthToken object.

		Args:
			token (str): The actual token used for authentication.
			expiration (int): The number of milliseconds this token is valid for.
			expiration_date (datetime.pyi): The datetime that this token expires.
		"""
		self.token = token
		self.expiration = expiration
		self.expiration_date = expiration_date
	
	def get_token(self):
		"""
		Simple getter for token.

		Returns:
			token (str): The actual token used for authentication.
		"""
		return self.token
	
	def get_expiration(self):
		"""
		Simple getter for expiration.

		Returns:
			expiration (int): The number of milliseconds this token is valid for.
		"""
		return self.expiration

	def get_expiration_date(self):
		"""
		Simple getter for expiration_date.

		Returns:
			expiration_date (datetime.pyi): The datetime that this token expires.
		"""
		return self.expiration_date



import unittest

from aep_sdk.API import API
from aep_sdk.ParameterClasses.AuthToken import AuthToken


class TestSDK(unittest.TestCase):
    testUpload128 = True
    testUpload256 = True
    testUpload500 = True
    testUploadError = True
    testMultipleFilesSuccess = True
    testMultipleFilesFailure = True
    testMultipleFilesSuccessLarge = True
    testMultipleFilesFailureLarge = True
    testUploadAll = True

    def setUp(self):
        self.api = API('config.json')
        self.dataset_id = "5e29e7e984479018a93e70a7"

    def testHelp(self):
        self.assertIsNone(help(API))

    def testBadAuth(self):
        self.api.access_token = AuthToken("eyJ4NXUiOiJpbXNfbmExLWtleS0xLmNlciIsImFsZyI6IlJTMjU2In0.eyJpZCI6IjE1ODA3NTU5"
                                          "MzM0OTFfNTM3ZDZiYWQtNmJjOS00YWFjLWEwZTktMDEzM2YyOTFiNzYxX3VlMSIsImNsaWVudF9p"
                                          "ZCI6ImQ4YjY1Y2E3NWVlNDRiOGNhOWJmODdiNmZkYzBhMTc0IiwidXNlcl9pZCI6IkQ5Q0I3OEEy"
                                          "NURBRTE0QkMwQTQ5NUMyMUB0ZWNoYWNjdC5hZG9iZS5jb20iLCJzdGF0ZSI6IntcInNlc3Npb25c"
                                          "IjpcImh0dHBzOi8vaW1zLW5hMS5hZG9iZWxvZ2luLmNvbS9pbXMvc2Vzc2lvbi92MS9aakExT1da"
                                          "ak1Ea3RabU5tWmkwME1qTTFMV0V5WkRRdFlqUmlNREV3TnpOalpXTTBMUzFFT1VOQ056aEJNalZF"
                                          "UVVVeE5FSkRNRUUwT1RWRE1qRkFkR1ZqYUdGalkzUXVZV1J2WW1VdVkyOXRcIn0iLCJ0eXBlIjoi"
                                          "YWNjZXNzX3Rva2VuIiwiYXMiOiJpbXMtbmExIiwiZmciOiJVRkFLWUpFMkhQRTVKUFVQRzZBTFlQ"
                                          "UUFEVT09PT09PSIsIm1vaSI6IjU0YmVlZjg3IiwiYyI6IlRrZnhXK3dwRStzZk9TbGc1RlZITlE9"
                                          "PSIsImV4cGlyZXNfaW4iOiI4NjQwMDAwMCIsInNjb3BlIjoib3BlbmlkLHNlc3Npb24sQWRvYmVJ"
                                          "RCxyZWFkX29yZ2FuaXphdGlvbnMsYWRkaXRpb25hbF9pbmZvLnByb2plY3RlZFByb2R1Y3RDb250"
                                          "ZXh0IiwiY3JlYXRlZF9hdCI6IjE1ODA3NTU5MzM0OTEifQ.psJCN3iFkzMx9bgkQBB4cDBHzvuHK"
                                          "6eLT146iw1z-89kf0m0iPqshJuX3ddToUWp3hXEbZWkr9Ta1BezbjTvSnpgtYbNFAs4M2mYnVHpz"
                                          "qCgJQxI41JzQKHAqj94_dHNJIWvHJERnME1L9dX0DHSmFSTSZVwOUZWT7HFdZg-2wPTG4wY3VRVm"
                                          "iwVmmW3lQAJ5aL6N7O1rWUqEEb9tXHM9UJSKeFTdlsmyAX_MV9TK9-zB5kDpkhMK41rQiwUVWzCk"
                                          "B1gawJPutweGv5GiUieOOlwLz0GfD5oH5aoA8FYXt9_hFziQPP55yVoxbYWuOPFMiqRBWmL_zbne"
                                          "8D4Kn7Uwg",
                                          7907987979, "0")
        self.assertFalse(self.api.validate(self.dataset_id))

    def testBadConfig(self):
        self.assertFalse(self.api.init_config('badConfig.json'))

    def test_id_validation(self):
        self.assertTrue(self.api.validate(self.dataset_id))
        self.assertFalse(self.api.validate("dijf0fhjw0hf0w"))
        self.assertFalse(self.api.validate(""))

    @unittest.skipUnless(testUpload128, "Not currently testing")
    def test_upload_128(self):
        self.assertEqual(self.api.upload(['test128.json'], self.dataset_id), "success")

    @unittest.skipUnless(testUpload256, "Not currently testing")
    def test_upload_256(self):
        self.assertEqual(self.api.upload(['test256.json'], self.dataset_id), "success")

    @unittest.skipUnless(testUpload500, "Not currently testing")
    def test_upload_large(self):
        self.assertEqual(self.api.upload(['test500.json'], self.dataset_id), "success")

    @unittest.skipUnless(testUploadError, "Not currently testing")
    def test_upload_error(self):
        self.assertEqual(self.api.upload(['testError.json'], self.dataset_id), "failure")

    @unittest.skipUnless(testMultipleFilesSuccess, "Not currently testing")
    def test_upload_multiple_success(self):
        self.assertEqual(self.api.upload(['test1.json', 'test128.json'], self.dataset_id), "success")

    @unittest.skipUnless(testMultipleFilesFailure, "Not currently testing")
    def test_upload_multiple_failure(self):
        self.assertEqual(self.api.upload(['test1.json', 'testError.json'], self.dataset_id), "failure")

    @unittest.skipUnless(testMultipleFilesSuccessLarge, "Not currently testing")
    def test_upload_multiple_success_large(self):
        self.assertEqual(self.api.upload(['test1.json', 'test500.json'], self.dataset_id), "success")

    @unittest.skipUnless(testMultipleFilesFailureLarge, "Not currently testing")
    def test_upload_multiple_failure_large(self):
        self.assertEqual(self.api.upload(['test500.json', 'testError.json'], self.dataset_id), "failure")

    @unittest.skipUnless(testUploadAll, "Not currently testing")
    def test_upload_all(self):
        self.assertEqual(self.api.upload(['test128.json', 'test256.json', 'test500.json'], self.dataset_id), "success")


if __name__ == '__main__':
    unittest.main()
